==> gazie7.30.zip: gazie/modules/acquis/menu.italian.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['acquis'] = array('name' => "Acquisti",
    'title' => "Gestione Acquisti",
    'm2' => array(1 => array("Gestione Preventivi/Offerte ", "Preventivi/Offerte"),
        2 => array("Gestione dei D.d.T. a Fornitori", "D.d.T."),
        3 => array("Fatture d'Acquisto", "Fatture"),
        4 => array("Lista degli ordini di bonifico/addebito", "Bonifici-Addebiti"),
        5 => array("Gestione dell'Archivio dei Fornitori", "Fornitori"),
        6 => array("Visualizzazione e Stampa della Lista dei Debiti verso Fornitori", "Lista Debiti"),
        7 => array("Stampa modulo Scheda Carburante", "Scheda Carburante"),
        8 => array("Scadenzario a partite aperte", "Scadenzario"),
        9 => array("Agenti di Fornitori", "Agenti"),
        10 => array("Gestione Ordini a Fornitori", "Ordini")
    ),
    'm3' => array(1 => array("Richiedi un preventivo a fornitore", "Richiedi preventivo"),
        2 => array("Ordine a fornitore ", "Ordina a fornitore"),
        3 => array("Emissione D.d.T. per reso a fornitore", "Emetti DdT di reso"),
        4 => array("Emissione D.d.T. per c/lavorazione", "Emetti DdT in c/lavorazione"),
        5 => array("Registrazione fattura di acquisto merce", "Registra fattura di acquisto"),
        6 => array("Registrazione nota credito per merce", "Registra nota credito da fornitore"),
        7 => array("Contabilizzazione fatture di acquisto", "Contabilizza fatture"),
        8 => array("Inserisci un nuovo fornitore", "Nuovo fornitore"),
        9 => array("Lista D.d.T. d'acqisto", "Lista D.d.T. d\'acquisto"),
        10 => array("Ricevuto DdT da fornitore", "Ricevuto DdT d\'acquisto"),
        11 => array("Pagamento di un debito vantato da un fornitore", "Pagamento debito verso fornitore"),
        12 => array("Report partite aperte", "Report partite aperte"),
        13 => array("Selezione e stampa stato fornitori", "Stato delle scadenze"),
        14 => array("Inserimento nuovo agente di fornitori", "Nuovo agente"),
        15 => array("Stampa lista fornitori", "Lista fornitori"),
        16 => array("Acquistato bene ammortizzabile", "Acquisto bene ammortizzabile"),
        17 => array("Pagamento RiBa fornitori", "Registra disposizione pagamenti"),
		18 => array("Ordine automatico fornitore", "Ordine automatico fornitore"),
		19 => array("Acquisisci fattura elettronica", "Acquisisci fattura elettronica"),
        20 => array("Ricevuto DdT ritorno da lavorazione", "Ricevuto DdT ritorno da lavorazione")
    )
);
?>

==> gazie8.00.zip: gazie/modules/acquis/menu.italian.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['acquis'] = array('name' => " Acquisti",
    'title' => "Gestione Acquisti",
    'm2' => array(1 => array("Gestione Preventivi/Offerte ", "Preventivi/Offerte"),
        2 => array("Gestione dei D.d.T. a Fornitori", "D.d.T."),
        3 => array("Fatture d'Acquisto", "Fatture"),
        4 => array("Lista degli ordini di bonifico/addebito", "Bonifici-Addebiti"),
        5 => array("Gestione dell'Archivio dei Fornitori", "Fornitori"),
        6 => array("Visualizzazione e Stampa della Lista dei Debiti verso Fornitori", "Lista Debiti"),
        7 => array("Stampa modulo Scheda Carburante", "Scheda Carburante"),
        8 => array("Scadenzario a partite aperte", "Scadenzario"),
        9 => array("Agenti di Fornitori", "Agenti"),
        10 => array("Gestione Ordini a Fornitori", "Ordini")
    ),
    'm3' => array(1 => array("Richiedi un preventivo a fornitore", "Richiedi preventivo"),
        2 => array("Ordine a fornitore ", "Ordina a fornitore"),
        3 => array("Emissione D.d.T. per reso a fornitore", "Emetti DdT di reso"),
        4 => array("Emissione D.d.T. per c/lavorazione", "Emetti DdT in c/lavorazione"),
        5 => array("Registrazione fattura di acquisto merce", "Registra fattura di acquisto"),
        6 => array("Registrazione nota credito per merce", "Registra nota credito da fornitore"),
        7 => array("Contabilizzazione fatture di acquisto", "Contabilizza fatture"),
        8 => array("Inserisci un nuovo fornitore", "Nuovo fornitore"),
        9 => array("Lista D.d.T. d'acqisto", "Lista D.d.T. d\'acquisto"),
        10 => array("Ricevuto DdT da fornitore", "Ricevuto DdT d\'acquisto"),
        11 => array("Pagamento di un debito vantato da un fornitore", "Pagamento debito verso fornitore"),
        12 => array("Report partite aperte", "Report partite aperte"),
        13 => array("Selezione e stampa stato fornitori", "Stato delle scadenze"),
        14 => array("Inserimento nuovo agente di fornitori", "Nuovo agente"),
        15 => array("Stampa lista fornitori", "Lista fornitori"),
        16 => array("Acquistato bene ammortizzabile", "Acquisto bene ammortizzabile"),
        17 => array("Pagamento RiBa fornitori", "Registra disposizione pagamenti"),
        18 => array("Ordine automatico fornitore", "Ordine automatico fornitore"),
        19 => array("Acquisisci fattura elettronica", "Acquisisci fattura elettronica"),
        20 => array("Ricevuto DdT ritorno da lavorazione", "Ricevuto DdT ritorno da lavorazione"),
        21 => array("Genera XML-CBI bonifico", "Genera XML-CBI bonifico")
    )
);
?>
